"""
__version__.py
~~~~~~~~~~~~~~

Information about the current version of the py-package-template package.
"""

__title__ = 'elasticcode'
__description__ = 'An elastic, distributed python compute platform'
__version__ = '0.0.9'
__author__ = 'Darren Govoni'
__author_email__ = 'darren@ontrenet.com'
__license__ = 'MIT'
__url__ = 'https://github.com/radiantone/elasticcode'
